# 1.1.0 [2023-06-15] 

- Improve environment variable handling.
- Reject config file with unknown sections or directives.

# 1.0.0 [2023-06-09]

- Initial public release of Python version of nihtest.
